# papanda

Useful tools for statistical data exploration.

Version 0.0.1a2 includes tests for detecting outliers:

1) Generalized ESD Test for Outliers (GESD) for normal distribution;
2) Cochran's test for detecting outliers in a set of variances;
3) Greenwood's test for exponential distribution;
4) Modified boxplot;
5) Trimmed mean.

See example in func_examples.ipynb github

Compliant ISO 16269-4:2010

**Release notes 0.0.1a2**

Buglists:
1) fixed errors in the docstring;
2) fixed problems with access to tables for statistical tests;
3) fixed errors in func_examples.ipynb.

**Release notes 0.0.1a3**

Buglists:
1) fixed errors in setup.py and setup.cfg.

**Release notes 0.0.1a4**

Buglists:
1) fixed errors in setup.py and setup.cfg.